<?php

namespace Drupal\user_not_role;

/**
 * Provides a wrapper around user_role_names().
 */
trait UserRolesTrait {

  /**
   * A callback of \user_role_names().
   *
   * @var callable
   */
  protected $userRoleNames = NULL;

  /**
   * Sets an optional callback to use instead of \user_role_names().
   *
   * @param callable $func
   *   The function.
   */
  public function setUserRoleNames(callable $func): void {
    $this->userRoleNames = $func;
  }

  /**
   * Gets the user role names.
   *
   * @return string[]
   *   The user role ids.
   */
  public function getUserRoles(): array {
    if ($this->userRoleNames !== NULL && is_callable($this->userRoleNames)) {
      $callback = $this->userRoleNames;
      return $callback();
    }
    return \user_role_names();
  }

}
